Proto Plus for Python
=====================

|release level| |ci| |docs| |codecov|

    Beautiful, Pythonic protocol buffers.

This is a wrapper around `protocol buffers`_. Protocol buffers is a
specification format for APIs, such as those inside Google.
This library provides protocol buffer message classes and objects that
largely behave like native Python types.

.. _protocol buffers: https://developers.google.com/protocol-buffers/


Documentation
-------------

`Documentation`_ is available on Read the Docs.

.. _documentation: https://proto-plus-python.readthedocs.io/


Disclaimer
----------

This is not an official Google product.


.. |release level| image:: https://img.shields.io/badge/release%20level-alpha-red.svg?style&#x3D;flat
  :target: https://cloud.google.com/terms/launch-stages
.. |docs| image:: https://readthedocs.org/projects/proto-plus-python/badge/?version=latest
  :target: https://gapic-generator-python.readthedocs.io/
.. |ci| image:: https://circleci.com/gh/googleapis/proto-plus-python.svg?style=shield
  :target: https://circleci.com/gh/googleapis/proto-plus-python
.. |codecov| image:: https://codecov.io/gh/googleapis/proto-plus-python/graph/badge.svg
  :target: https://codecov.io/gh/googleapis/proto-plus-python
